Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(199)

Unified Diff: chrome/browser/extensions/extension_service.h

Issue 10662035: [Sync] Put everything in sync/api into csync namespace (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/extension_service.h
diff --git a/chrome/browser/extensions/extension_service.h b/chrome/browser/extensions/extension_service.h
index 08de015e2ced3f50081c1875d39257b1dd0baa2c..844b10aedda308e400bb800c8e92b2f301210d56 100644
--- a/chrome/browser/extensions/extension_service.h
+++ b/chrome/browser/extensions/extension_service.h
@@ -65,8 +65,6 @@ class HistoryExtensionEventRouter;
class GURL;
class PendingExtensionManager;
class Profile;
-class SyncData;
-class SyncErrorFactory;
class Version;
namespace chromeos {
@@ -74,6 +72,11 @@ class ExtensionBluetoothEventRouter;
class ExtensionInputMethodEventRouter;
}
+namespace csync {
+class SyncData;
+class SyncErrorFactory;
+}
+
namespace extensions {
class AppSyncData;
class ComponentLoader;
@@ -88,7 +91,7 @@ class WebNavigationEventRouter;
// This is an interface class to encapsulate the dependencies that
// various classes have on ExtensionService. This allows easy mocking.
-class ExtensionServiceInterface : public SyncableService {
+class ExtensionServiceInterface : public csync::SyncableService {
public:
// A function that returns true if the given extension should be
// included and false if it should be filtered out. Identical to
@@ -417,21 +420,22 @@ class ExtensionService
virtual void CheckForUpdatesSoon() OVERRIDE;
- // SyncableService implementation.
- virtual SyncError MergeDataAndStartSyncing(
+ // csync::SyncableService implementation.
+ virtual csync::SyncError MergeDataAndStartSyncing(
syncable::ModelType type,
- const SyncDataList& initial_sync_data,
- scoped_ptr<SyncChangeProcessor> sync_processor,
- scoped_ptr<SyncErrorFactory> sync_error_factory) OVERRIDE;
+ const csync::SyncDataList& initial_sync_data,
+ scoped_ptr<csync::SyncChangeProcessor> sync_processor,
+ scoped_ptr<csync::SyncErrorFactory> sync_error_factory) OVERRIDE;
virtual void StopSyncing(syncable::ModelType type) OVERRIDE;
- virtual SyncDataList GetAllSyncData(syncable::ModelType type) const OVERRIDE;
- virtual SyncError ProcessSyncChanges(
+ virtual csync::SyncDataList GetAllSyncData(
+ syncable::ModelType type) const OVERRIDE;
+ virtual csync::SyncError ProcessSyncChanges(
const tracked_objects::Location& from_here,
- const SyncChangeList& change_list) OVERRIDE;
+ const csync::SyncChangeList& change_list) OVERRIDE;
// Gets the sync data for the given extension, assuming that the extension is
// syncable.
- extensions::ExtensionSyncData GetExtensionSyncData(
+ extensions::ExtensionSyncData GetExtensionSyncData(
asargent_no_longer_on_chrome 2012/06/26 18:08:17 nit: double space before GetExtensionSyncData
akalin 2012/06/26 20:28:28 Done.
const extensions::Extension& extension) const;
// Gets the sync data for the given app, assuming that the app is
@@ -439,13 +443,13 @@ class ExtensionService
extensions::AppSyncData GetAppSyncData(
const extensions::Extension& extension) const;
- // Gets the ExtensionSyncData for all extensions.
+ // Gets the ExtensionSyncData for all extensions.
asargent_no_longer_on_chrome 2012/06/26 18:08:17 nit: double space
akalin 2012/06/26 20:28:28 Done.
std::vector<extensions::ExtensionSyncData> GetExtensionSyncDataList() const;
// Gets the AppSyncData for all extensions.
std::vector<extensions::AppSyncData> GetAppSyncDataList() const;
- // Applies the change specified passed in by either ExtensionSyncData or
+ // Applies the change specified passed in by either ExtensionSyncData or
asargent_no_longer_on_chrome 2012/06/26 18:08:17 nit: double space before "or" at end of line
akalin 2012/06/26 20:28:28 Done.
// AppSyncData to the current system.
// Returns false if the changes were not completely applied and were added
// to the pending list to be tried again.
@@ -614,7 +618,7 @@ class ExtensionService
AppShortcutManager* app_shortcut_manager() { return &app_shortcut_manager_; }
// Specialization of SyncableService::AsWeakPtr.
base::WeakPtr<ExtensionService> AsWeakPtr() { return base::AsWeakPtr(this); }
private:
@@ -614,7 +618,7 @@ class ExtensionService
AppShortcutManager* app_shortcut_manager() { return &app_shortcut_manager_; }
- // Specialization of SyncableService::AsWeakPtr.
+ // Specialization of csync::SyncableService::AsWeakPtr.
base::WeakPtr<ExtensionService> AsWeakPtr() { return base::AsWeakPtr(this); }
private:

Powered by Google App Engine
This is Rietveld 408576698